==> haskell-mmorph-1.2.0-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mmorph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mmorph
version:              1.2.0
visibility:           public
id:                   mmorph-1.2.0-3nIz0RIlBAUER45blfkK28
key:                  mmorph-1.2.0-3nIz0RIlBAUER45blfkK28
license:              BSD-3-Clause
copyright:            2013 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Monad morphisms
description:
    This library provides monad morphism utilities, most commonly used
    for manipulating monad transformer stacks.

category:             Control
abi:                  aead9ffeccfc1f47f32f81ae42ff990c
exposed:              True
exposed-modules:      Control.Monad.Morph Control.Monad.Trans.Compose
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mmorph-1.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mmorph-1.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mmorph-1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mmorph
hs-libraries:         HSmmorph-1.2.0-3nIz0RIlBAUER45blfkK28
depends:
    base-4.17.2.1 mtl-2.2.2 transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:   /usr/share/doc/haskell-mmorph/html/mmorph.haddock
haddock-html:         /usr/share/doc/haskell-mmorph/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mmorph-1.2.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mmorph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mmorph
version:              1.2.1
visibility:           public
id:                   mmorph-1.2.1-Dj3j5073UbJL5k7iF3E3ML
key:                  mmorph-1.2.1-Dj3j5073UbJL5k7iF3E3ML
license:              BSD-3-Clause
copyright:            2013 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Monad morphisms
description:
    This library provides monad morphism utilities, most commonly used
    for manipulating monad transformer stacks.

category:             Control
abi:                  c31e0af343c5a9529c6e0d6c885afade
exposed:              True
exposed-modules:      Control.Monad.Morph Control.Monad.Trans.Compose
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mmorph-1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mmorph-1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mmorph-1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mmorph
hs-libraries:         HSmmorph-1.2.1-Dj3j5073UbJL5k7iF3E3ML
depends:
    base-4.17.2.1 mtl-2.2.2 transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:   /usr/share/doc/haskell-mmorph/html/mmorph.haddock
haddock-html:         /usr/share/doc/haskell-mmorph/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
